@@ -1,3 +1,10 @@
+/**
+ * Copyright IBM Corp. 2016, 2018
+ *
+ * This source code is licensed under the Apache-2.0 license found in the
+ * LICENSE file in the root directory of this source tree.
+ */
+
 /**
  * Use the local `localCompare` with the `numeric` option to sort two,
  * potentially alpha-numeric, strings in a list of items.
@@ -14,22 +21,20 @@ export var defaultCompareItems = function defaultCompareItems(itemA, itemB, _ref
     numeric: true
   });
 };
-
 /**
  * Default sorting algorithm for options in a selection control
  */
+
 export var defaultSortItems = function defaultSortItems(items, _ref2) {
   var selectedItems = _ref2.selectedItems,
       itemToString = _ref2.itemToString,
       compareItems = _ref2.compareItems,
       _ref2$locale = _ref2.locale,
-      locale = _ref2$locale === undefined ? 'en' : _ref2$locale,
-      parent = _ref2.parent;
+      locale = _ref2$locale === void 0 ? 'en' : _ref2$locale;
   return items.sort(function (itemA, itemB) {
     var hasItemA = selectedItems.includes(itemA);
-    var hasItemB = selectedItems.includes(itemB);
+    var hasItemB = selectedItems.includes(itemB); // Prefer whichever item is in the `selectedItems` array first
 
-    // Prefer whichever item is in the `selectedItems` array first
     if (hasItemA && !hasItemB) {
       return -1;
     }
@@ -38,20 +43,6 @@ export var defaultSortItems = function defaultSortItems(items, _ref2) {
       return 1;
     }
 
-    if (parent) {
-      var checkedItemA = itemA.checked;
-      var checkedItemB = itemB.checked;
-
-      // Prefer whichever checked item be first
-      if (checkedItemA && !checkedItemB) {
-        return -1;
-      }
-
-      if (checkedItemB && !checkedItemA) {
-        return 1;
-      }
-    }
-
     return compareItems(itemToString(itemA), itemToString(itemB), {
       locale: locale
     });
